@@ -6,8 +6,7 @@
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef MAINWINDOW_H
-#define MAINWINDOW_H
+#pragma once
 
 /** @file mainwindow.h - main application window */
 
@@ -21,6 +20,7 @@
 
 #include <QVector>
 #include <QMap>
+#include <QPointer>
 
 class QDragEnterEvent;
 class QHideEvent;
@@ -33,8 +33,10 @@ class QMenu;
 class QAction;
 class KToggleAction;
 class KToolBarPopupAction;
+class KHamburgerMenu;
 class AlarmListModel;
 class AlarmListView;
+class DatePicker;
 class NewAlarmAction;
 class TemplateDlg;
 class ResourceSelector;
@@ -54,6 +56,7 @@ public:
     KAEvent            selectedEvent() const;
     void               editAlarm(EditAlarmDlg*, const KAEvent&);
     void               clearSelection();
+    QMenu*             resourceContextMenu();
     bool               eventFilter(QObject*, QEvent*) override;
 
     static void        refresh();
@@ -79,8 +82,9 @@ protected:
     void           readProperties(const KConfigGroup&) override;
 
 private Q_SLOTS:
+    void           slotInitHamburgerMenu();
     void           slotNew(EditAlarmDlg::Type);
-    void           slotNewFromTemplate(const KAEvent&);
+    void           slotNewFromTemplate(const KAlarmCal::KAEvent&);
     void           slotNewTemplate();
     void           slotCopy();
     void           slotModify();
@@ -96,7 +100,7 @@ private Q_SLOTS:
     void           slotTemplates();
     void           slotTemplatesEnd();
     void           slotPreferences();
-    void           slotShowMenubar();
+    void           slotToggleMenubar(bool dontShowWarning);
     void           slotConfigureKeys();
     void           slotConfigureNotifications();
     void           slotConfigureToolbar();
@@ -118,8 +122,10 @@ private Q_SLOTS:
     void           slotFindActive(bool);
     void           updateTrayIconAction();
     void           slotToggleResourceSelector();
+    void           slotToggleDateNavigator();
     void           slotCalendarStatusChanged();
     void           slotAlarmListColumnsChanged();
+    void           datesSelected(const QVector<QDate>& dates);
     void           resourcesResized();
     void           showMenuErrorMessage();
     void           showErrorMessage(const QString&);
@@ -133,6 +139,8 @@ private:
     void           initActions();
     void           selectionCleared();
     void           setEnableText(bool enable);
+    void           setPanelWidth(int panelWidth);
+    void           setSplitterSizes();
     void           initUndoMenu(QMenu*, Undo::Type);
     void           slotDelete(bool force);
     static void    enableTemplateMenuItem(bool);
@@ -143,9 +151,13 @@ private:
     AlarmListModel*      mListFilterModel;
     AlarmListView*       mListView;
     ResourceSelector*    mResourceSelector;    // resource selector widget
+    DatePicker*          mDatePicker;          // date navigator widget
     QSplitter*           mSplitter;            // splits window into list and resource selector
+    QWidget*             mPanel;               // panel containing resource selector & date navigator
     QMap<EditAlarmDlg*, KAEvent> mEditAlarmMap; // edit alarm dialogs to be handled by this window
+    KToggleAction*       mActionShowMenuBar;
     KToggleAction*       mActionToggleResourceSel;
+    KToggleAction*       mActionToggleDateNavigator;
     QAction*             mActionImportAlarms;
     QAction*             mActionExportAlarms;
     QAction*             mActionExport;
@@ -166,12 +178,14 @@ private:
     KToggleAction*       mActionToggleTrayIcon;
     KToggleAction*       mActionShowArchived;
     KToggleAction*       mActionSpreadWindows;
-    QMenu*               mActionsMenu;
-    QMenu*               mContextMenu;
+    KHamburgerMenu*      mHamburgerMenu;
+    QPointer<QMenu>      mContextMenu;
+    QPointer<QMenu>      mResourceContextMenu;
     QMap<QAction*, int>  mUndoMenuIds;         // items in the undo/redo menu, in order of appearance
     int                  mResourcesWidth {-1}; // width of resource selector widget
     bool                 mHiddenTrayParent {false}; // on session restoration, hide this window
     bool                 mShowResources;       // show resource selector
+    bool                 mShowDateNavigator;   // show date navigator
     bool                 mShowArchived;        // include archived alarms in the displayed list
     bool                 mShown {false};       // true once the window has been displayed
     bool                 mActionEnableEnable;  // Enable/Disable action is set to "Enable"
@@ -179,6 +193,5 @@ private:
     bool                 mResizing {false};    // window resize is in progress
 };
 
-#endif // MAINWINDOW_H
 
 // vim: et sw=4:
